==> billogram-foundation-3.10.0.tgz: package/modules/components/radio/RadioButtonGroupContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import radioButtonGroupChange from './redux/radioButtonGroupChange';


export const changeType = actionName('CHANGE');

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing RadioButtonGroup component.');

    const RadioButtonGroupContainer = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            path: PropTypes.string.isRequired,
            root: PropTypes.string.isRequired,
            // ---
            actionTypePrefix: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { options, value } = getComponentState(state, props);
        return {
            options,
            value
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'RADIO-BUTTON-GROUP';

        return {
            onChange: (value) => dispatch(radioButtonGroupChange({ path, root, type: changeType(actionTypePrefix), value }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(RadioButtonGroupContainer);

};

==> billogram-foundation-3.11.0.tgz: package/modules/components/radio/RadioButtonGroupContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import radioButtonGroupChange from './redux/radioButtonGroupChange';


export const changeType = actionName('CHANGE');

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing RadioButtonGroup component.');

    const RadioButtonGroupContainer = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { options, value } = getComponentState(state, props);
        return {
            options,
            value
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'RADIO-BUTTON-GROUP';

        return {
            onChange: (value) => dispatch(radioButtonGroupChange({ custom, path, root, type: changeType(actionTypePrefix), value }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(RadioButtonGroupContainer);

};
